@@ -1,17 +1,22 @@
 """
 This file is part of python-none-objects library.
 
-python-none-objects is free software: you can redistribute it and/or modify
-it under the terms of the GNU Lesser General Public License as published by
-the Free Software Foundation, either version 3 of the License, or
-(at your option) any later version.
+python-none-objects is free software:
+you can redistribute it and/or modify it under the terms
+of the GNU Lesser General Public License
+as published by the Free Software Foundation,
+either version 3 of the License,
+or (at your option) any later version.
 
-python-none-objects is distributed in the hope that it will be useful,
-but WITHOUT ANY WARRANTY; without even the implied warranty of
+python-none-objects is distributed in the hope
+that it will be useful,
+but WITHOUT ANY WARRANTY;
+without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 See the GNU Lesser General Public License for more details.
 
-You should have received a copy of the GNU Lesser General Public License
+You should have received a copy of
+the GNU Lesser General Public License
 along with python-none-objects.
 If not, see <http://www.gnu.org/licenses/>.
 
@@ -35,6 +40,7 @@ def foo_collection(x: Collection[str] = NoneCollection) -> bool:
     """
     Check typing for NoneCollection.
     """
+
     for y in x:
         print(f"foo {y}")
     return "toto" in x
@@ -44,6 +50,7 @@ def foo_iterable(x: Iterable[str] = NoneIterable) -> None:
     """
     Check typing for NoneIterable.
     """
+
     for y in x:
         print(f"foo {y}")
 
@@ -52,6 +59,7 @@ def foo_container(x: Container[str] = NoneContainer) -> bool:
     """
     Check typing for NoneContainer.
     """
+
     return "toto" in x
 
 
@@ -59,6 +67,7 @@ def foo_mapping(x: Mapping[str, str] = NoneMapping) -> None:
     """
     Check typing for NoneMapping.
     """
+
     for y, z in x.items():
         print(f"foo {y} bar {z}")
 
